@@ -1,4 +1,4 @@
-/* $Id: gdict-defbox.c,v 1.22 2004/04/27 05:23:04 gman Exp $ */
+/* $Id: gdict-defbox.c,v 1.23 2004/05/11 23:23:28 fherrera Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -482,6 +482,21 @@ insert_text_with_tags (GtkTextBuffer *buffer, GtkTextIter *iter, gchar *p, gint
 		gtk_text_buffer_apply_tag_by_name (buffer, "underline", &start, iter);
 }
 
+static void
+insert_link (GtkTextBuffer *buffer, GtkTextIter *iter, gchar *text, gint len)
+{
+	GtkTextTag *tag;
+
+	tag = gtk_text_buffer_create_tag (buffer, NULL,
+					  "foreground", "blue",
+					  "underline", PANGO_UNDERLINE_SINGLE,
+					  NULL);
+	g_object_set_data (G_OBJECT (tag), "page", text);
+
+	gtk_text_buffer_insert_with_tags (buffer, iter, text, len , tag, NULL);
+}
+
+
 /* defbox_add
  *
  * Adds a definition to the defbox, performing all necessary formatting
@@ -491,7 +506,7 @@ static void
 defbox_add (GDictDefbox *defbox, gchar *def) {
     GtkTextBuffer *buffer;
     GtkTextIter iter;
-    gchar *p, *q;
+    gchar *p, *q, *text;
     gint len;
     GdkFont *font;
     GdkColor *color;
@@ -578,7 +593,7 @@ defbox_add (GDictDefbox *defbox, gchar *def) {
         } else if (*p == '{') {
             font = gdict_pref.typefaces[TYPEFACE_EXAMPLE].font;
             color = gdict_pref.typefaces[TYPEFACE_EXAMPLE].color;
-            bold = FALSE;
+            bold = TRUE;
             italic = TRUE;
             underline = FALSE;
 			q = p;
@@ -588,9 +603,9 @@ defbox_add (GDictDefbox *defbox, gchar *def) {
 				 q++;
                         }				
 			len = length;
-			
-			insert_text_with_tags (buffer, &iter, ++p, len-1, bold, italic, underline);
-			
+			++p;	
+			text = g_strndup (p, len - 1);
+			insert_link (buffer, &iter, text, len - 1);
 			p += length;
 			length = 0;
         } else if (*p == ']' ) {
