@@ -69,7 +69,7 @@ gchar *
 escape_single_quotes 		(const gchar *string);
 
 gchar *	
-backslash_backslashes		(const gchar *string);
+backslash_special_characters	(const gchar *string);
 
 gchar *
 remove_mnemonic_character	(const gchar *string);
@@ -111,6 +111,9 @@ void
 gsearchtool_gconf_set_boolean 	(const gchar *key, 
 				 const gboolean flag);
 
+char *
+gsearchtool_gconf_get_string 	(const gchar *key);
+
 gchar *
 gsearchtool_unique_filename 	(const gchar *dir,
 				 const gchar *suffix);
