@@ -66,30 +66,31 @@ struct _FindOptionTemplate {
 	SearchConstraintType type;
 	gchar 	 *option;          /* the option string to pass to find or whatever */
 	gchar 	 *desc;            /* description */
+	gchar    *units;           /* units */
 	gboolean is_selected;     
 };
 	
 static FindOptionTemplate templates[] = {
-	{ SEARCH_CONSTRAINT_TEXT, "-exec grep -c '%s' {} \\;", N_("Contains the _text"), FALSE },
-	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_TIME_LESS, "-mtime -%d", N_("_Date modified less than (days)"), FALSE },
-	{ SEARCH_CONSTRAINT_TIME_MORE, "\\( -mtime +%d -o -mtime %d \\)", N_("Date modified more than (da_ys)"), FALSE },
-	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_NUMBER, "-size +%uc", N_("S_ize at least (kilobytes)"), FALSE }, 
-	{ SEARCH_CONSTRAINT_NUMBER, "-size -%uc", N_("Si_ze at most (kilobytes)"), FALSE },
-	{ SEARCH_CONSTRAINT_BOOL, "-size 0c \\( -type f -o -type d \\)", N_("File is empty"), FALSE },	
-	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_TEXT, "-user '%s'", N_("Owned by _user"), FALSE },
-	{ SEARCH_CONSTRAINT_TEXT, "-group '%s'", N_("Owned by _group"), FALSE },
-	{ SEARCH_CONSTRAINT_BOOL, "\\( -nouser -o -nogroup \\)", N_("Owner is unrecognized"), FALSE },
-	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_TEXT, "'!' -name '*%s*'", N_("Na_me does not contain"), FALSE },
-	{ SEARCH_CONSTRAINT_TEXT, "-regex '%s'", N_("Name matches regular e_xpression"), FALSE }, 
-	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden and backup files"), FALSE },
-	{ SEARCH_CONSTRAINT_BOOL, "-follow", N_("Follow symbolic links"), FALSE },
-	{ SEARCH_CONSTRAINT_BOOL, "INCLUDE_OTHER_FILESYSTEMS", N_("Include other filesystems"), FALSE },
-	{ SEARCH_CONSTRAINT_END, NULL, NULL, FALSE}
+	{ SEARCH_CONSTRAINT_TEXT, "'!' -type p -exec grep -c '%s' {} \\;", N_("Contains the _text"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, NULL, TRUE },
+	{ SEARCH_CONSTRAINT_TIME_LESS, "-mtime -%d", N_("_Date modified less than"), N_("days"), FALSE },
+	{ SEARCH_CONSTRAINT_TIME_MORE, "\\( -mtime +%d -o -mtime %d \\)", N_("Date modified more than"), N_("days"), FALSE },
+	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, NULL, TRUE },
+	{ SEARCH_CONSTRAINT_NUMBER, "\\( -size %uc -o -size +%uc \\)", N_("S_ize at least"), N_("kilobytes"), FALSE }, 
+	{ SEARCH_CONSTRAINT_NUMBER, "\\( -size %uc -o -size -%uc \\)", N_("Si_ze at most"), N_("kilobytes"), FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "-size 0c \\( -type f -o -type d \\)", N_("File is empty"), NULL, FALSE },	
+	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, NULL, TRUE },
+	{ SEARCH_CONSTRAINT_TEXT, "-user '%s'", N_("Owned by _user"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_TEXT, "-group '%s'", N_("Owned by _group"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "\\( -nouser -o -nogroup \\)", N_("Owner is unrecognized"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, NULL, TRUE },
+	{ SEARCH_CONSTRAINT_TEXT, "'!' -name '*%s*'", N_("Na_me does not contain"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_TEXT, "-regex '%s'", N_("Name matches regular e_xpression"), NULL, FALSE }, 
+	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, NULL, TRUE },
+	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden and backup files"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "-follow", N_("Follow symbolic links"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "INCLUDE_OTHER_FILESYSTEMS", N_("Include other filesystems"), NULL, FALSE },
+	{ SEARCH_CONSTRAINT_END, NULL, NULL, NULL, FALSE}
 }; 
 
 static GtkTargetEntry dnd_table[] = {
@@ -199,7 +200,7 @@ setup_case_insensitive_arguments (void)
 	g_spawn_command_line_sync ("grep -i 'string' /dev/null", NULL, &cmd_stderr, NULL, NULL);
 
 	if ((cmd_stderr != NULL) && (strlen (cmd_stderr) == 0)) {
-		templates[SEARCH_CONSTRAINT_CONTAINS_THE_TEXT].option = g_strdup ("-exec grep -i -c '%s' {} \\;");
+		templates[SEARCH_CONSTRAINT_CONTAINS_THE_TEXT].option = g_strdup ("'!' -type p -exec grep -i -c '%s' {} \\;");
 	}
 	g_free (cmd_stderr);
 
@@ -277,9 +278,10 @@ build_search_command (void)
 
 	setup_case_insensitive_arguments ();
 	
-	file_is_named_utf8 = (gchar *) gtk_entry_get_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry))));
+	file_is_named_utf8 = g_strdup ((gchar *) gtk_entry_get_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry)))));
 
 	if (!file_is_named_utf8 || !*file_is_named_utf8) {
+		g_free (file_is_named_utf8);
 		file_is_named_utf8 = g_strdup ("*");
 	} 
 	else {
@@ -289,7 +291,11 @@ build_search_command (void)
 		gnome_entry_prepend_history (GNOME_ENTRY(interface.file_is_named_entry), TRUE, file_is_named_utf8);
 
 		if (strstr (locale, "*") == NULL) {
+			gchar *tmp;
+		
+			tmp = file_is_named_utf8;
 			file_is_named_utf8 = g_strconcat ("*", file_is_named_utf8, "*", NULL);
+			g_free (tmp);
 		}
 		
 		g_free (locale);
@@ -313,35 +319,50 @@ build_search_command (void)
 	
 	command = g_string_new ("");
 	search_command.show_hidden_files = FALSE;
+	search_command.quick_mode = FALSE;
+	search_command.regex_string = NULL;
+	search_command.date_format_pref = NULL;
+	search_command.file_is_named_pattern = NULL;
 	
 	if ((GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) ||
 	    (interface.selected_constraints == NULL)) {
 	
 		gchar *locate;
 		gboolean disable_quick_search;
+		gboolean force_quick_search;
 		
 		locate = g_find_program_in_path ("locate");
-		file_is_named_backslashed = backslash_backslashes (file_is_named_locale);
+		file_is_named_backslashed = backslash_special_characters (file_is_named_locale);
 		file_is_named_escaped = escape_single_quotes (file_is_named_backslashed);
 
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		disable_quick_search = gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/disable_quick_search");
+		force_quick_search = gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/force_quick_search");
 		
-		if ((disable_quick_search != TRUE) && (locate != NULL) 
-		    && (is_path_in_home_folder (look_in_folder_locale) != TRUE) 
-		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)
-		    && (is_path_in_proc_folder (look_in_folder_locale) != TRUE) 
-		    && (is_path_in_dev_folder (look_in_folder_locale) != TRUE)
-		    && (is_path_in_var_folder (look_in_folder_locale) != TRUE)
-		    && (is_path_in_tmp_folder (look_in_folder_locale) != TRUE)) {	
-			g_string_append_printf (command, "%s %s '%s*%s'", 
-						locate,
-						locate_command_default_options,
-						look_in_folder_locale,
-						file_is_named_escaped);
+		if ((disable_quick_search != TRUE) && (locate != NULL)) {
+		    	if ((force_quick_search == TRUE) || 
+			    ((is_path_in_home_folder (look_in_folder_locale) != TRUE) 
+			     && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)
+			     && (is_path_in_proc_folder (look_in_folder_locale) != TRUE) 
+			     && (is_path_in_dev_folder (look_in_folder_locale) != TRUE)
+			     && (is_path_in_var_folder (look_in_folder_locale) != TRUE)
+			     && (is_path_in_tmp_folder (look_in_folder_locale) != TRUE))) {	
+				g_string_append_printf (command, "%s %s '%s*%s'", 
+							locate,
+							locate_command_default_options,
+							look_in_folder_locale,
+							file_is_named_escaped);
+				search_command.quick_mode = TRUE;
+		 	}
+			else {
+				g_string_append_printf (command, "find \"%s\" %s '%s' -xdev -print", 
+							look_in_folder_locale, 
+							find_command_default_name_option, 
+							file_is_named_escaped);
+			}
 		} 
 		else {
-			g_string_append_printf (command, "find \"%s\" '!' -type p %s '%s' -xdev -print", 
+			g_string_append_printf (command, "find \"%s\" %s '%s' -xdev -print", 
 						look_in_folder_locale, 
 						find_command_default_name_option, 
 						file_is_named_escaped);
@@ -353,11 +374,10 @@ build_search_command (void)
 		gboolean disable_mount_argument = FALSE;
 		
 		search_command.regex_matching_enabled = FALSE;
-		file_is_named_backslashed = backslash_backslashes (file_is_named_locale);
+		file_is_named_backslashed = backslash_special_characters (file_is_named_locale);
 		file_is_named_escaped = escape_single_quotes (file_is_named_backslashed);
-		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		
-		g_string_append_printf (command, "find \"%s\" '!' -type p  %s", 
+		g_string_append_printf (command, "find \"%s\" %s", 
 					look_in_folder_locale,
 					setup_find_name_options (file_is_named_escaped));
 	
@@ -384,7 +404,7 @@ build_search_command (void)
 					gchar *escaped;
 					gchar *regex;
 					
-					escaped = backslash_backslashes (constraint->data.text);
+					escaped = backslash_special_characters (constraint->data.text);
 					regex = escape_single_quotes (escaped);
 					
 					if (regex != NULL) {	
@@ -400,7 +420,7 @@ build_search_command (void)
 					gchar *backslashed;
 					gchar *locale;
 					
-					backslashed = backslash_backslashes (constraint->data.text);
+					backslashed = backslash_special_characters (constraint->data.text);
 					escaped = escape_single_quotes (backslashed);
 					
 					locale = g_locale_from_utf8 (escaped, -1, NULL, NULL, NULL);
@@ -421,6 +441,7 @@ build_search_command (void)
 			case SEARCH_CONSTRAINT_NUMBER:
 				g_string_append_printf (command,
 					  		templates[constraint->constraint_id].option,
+							(constraint->data.number * 1024),
 					  		(constraint->data.number * 1024));
 				g_string_append_c (command, ' ');
 				break;
@@ -450,7 +471,9 @@ build_search_command (void)
 		g_string_append (command, "-print ");
 	}
 	g_free (file_is_named_locale);
+	g_free (file_is_named_utf8);
 	g_free (file_is_named_backslashed);
+	g_free (file_is_named_escaped);
 	g_free (look_in_folder_locale);
 	
 	return g_string_free (command, FALSE);
@@ -537,7 +560,7 @@ update_search_counts (void)
 {
 	gchar  *title_bar_string = NULL;
 	gchar  *message_string = NULL;
-	gchar  *stopped_string = g_strdup ("");
+	gchar  *stopped_string = NULL;
 	gchar  *tmp;
 	gint   total_files;
 
@@ -563,7 +586,7 @@ update_search_counts (void)
 						  total_files);
 	}
 
-	if (strlen (stopped_string) > 0) {
+	if (stopped_string != NULL) {
 		tmp = message_string;
 		message_string = g_strconcat (message_string, " ", stopped_string, NULL);
 		g_free (tmp);
@@ -685,10 +708,14 @@ set_constraint_selected_state (gint 		constraint_id,
 			gtk_option_menu_set_history (GTK_OPTION_MENU(interface.constraint_menu), index);
 			interface.selected_constraint = (long)index;
 			gtk_widget_set_sensitive (interface.add_button, TRUE);
+			gtk_widget_set_sensitive (interface.constraint_menu, TRUE);
+			gtk_widget_set_sensitive (interface.constraint_menu_label, TRUE);
 			return;
 		}
 	}
 	gtk_widget_set_sensitive (interface.add_button, FALSE);
+	gtk_widget_set_sensitive (interface.constraint_menu, FALSE);
+	gtk_widget_set_sensitive (interface.constraint_menu_label, FALSE);
 }
 
 void
@@ -1225,6 +1252,12 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		gtk_widget_hide (interface.stop_button);
 		gtk_widget_show (interface.find_button);
 
+		/* Free the gchar fields of search_command structure. */
+		g_free (search_data->look_in_folder);
+		g_free (search_data->file_is_named_pattern);
+		g_free (search_data->regex_string);
+		g_free (search_data->date_format_pref);
+
 		g_io_channel_shutdown (ioc, TRUE, NULL);
 		return FALSE;
 	}
@@ -1312,28 +1345,59 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 				
 				GtkWidget *dialog;
 				
-				error_msgs = g_string_prepend (error_msgs, 
-				     _("While searching the following errors were reported.\n\n"));
-				
 				if (truncate_error_msgs) {
 					error_msgs = g_string_append (error_msgs, 
 				     		_("\n... Too many errors to display ..."));
 				}
 				
-				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
-		                	                           GTK_DIALOG_DESTROY_WITH_PARENT,
-						                   GTK_MESSAGE_ERROR,
-							           GTK_BUTTONS_OK,
-							           _("Error while searching for files."),
-							           error_msgs->str,
-							           NULL);
+				if (search_command.quick_mode != TRUE) {
+				     
+					dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                		                           GTK_DIALOG_DESTROY_WITH_PARENT,
+							                   GTK_MESSAGE_ERROR,
+								           GTK_BUTTONS_OK,
+								           _("The search results may be invalid."
+									     "  There were errors while performing this search."),
+								           NULL,
+								           NULL);			
 				
-				g_signal_connect (G_OBJECT (dialog),
-					"response",
-					G_CALLBACK (gtk_widget_destroy), NULL);
+					gsearch_alert_dialog_set_secondary_label (GSEARCH_ALERT_DIALOG (dialog), NULL);							   
+					gsearch_alert_dialog_set_details_label (GSEARCH_ALERT_DIALOG (dialog), error_msgs->str);
+					
+					g_signal_connect (G_OBJECT (dialog),
+						"response",
+						G_CALLBACK (gtk_widget_destroy), NULL);
+					
+					gtk_widget_show (dialog);
+				}
+				else {
+					GtkWidget *button;
+								       			       
+					dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                		                           GTK_DIALOG_DESTROY_WITH_PARENT,
+							                   GTK_MESSAGE_ERROR,
+								           GTK_BUTTONS_CANCEL,
+								           _("The search results may be invalid."
+									     "  Do you want to disable the quick search feature?"),
+								           NULL,
+								           NULL);
+									   
+					gsearch_alert_dialog_set_secondary_label (GSEARCH_ALERT_DIALOG (dialog), NULL);							   
+					gsearch_alert_dialog_set_details_label (GSEARCH_ALERT_DIALOG (dialog), error_msgs->str);
+					
+					button = gsearchtool_button_new_with_stock_icon (_("Disable _Quick Search"), GTK_STOCK_OK);
+					GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+					gtk_widget_show (button);
+
+					gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+					gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 				
-				gtk_widget_show (dialog);
-	
+					g_signal_connect (G_OBJECT (dialog),
+						"response",
+						G_CALLBACK (disable_quick_search_cb), NULL);
+					
+					gtk_widget_show (dialog);
+				}
 			}
 			truncate_error_msgs = FALSE;
 			g_string_truncate (error_msgs, 0);
@@ -1373,6 +1437,12 @@ spawn_search_command (gchar *command)
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
 		g_strfreev (argv);
+		
+		/* Free the gchar fields of search_command structure. */
+		g_free (search_command.look_in_folder);
+		g_free (search_command.file_is_named_pattern);
+		g_free (search_command.regex_string);
+		g_free (search_command.date_format_pref);
 		return;
 	}	
 
@@ -1395,6 +1465,13 @@ spawn_search_command (gchar *command)
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
+		g_strfreev (argv);
+		
+		/* Free the gchar fields of search_command structure. */
+		g_free (search_command.look_in_folder);
+		g_free (search_command.file_is_named_pattern);
+		g_free (search_command.regex_string);
+		g_free (search_command.date_format_pref);
 		return;
 	}
 	
@@ -1402,6 +1479,9 @@ spawn_search_command (gchar *command)
 	search_command.aborted = FALSE;
 	search_command.running = RUNNING; 
 	search_command.pixbuf_hash = g_hash_table_new (g_str_hash, g_str_equal);
+	
+	/* Get value of nautilus date_format key */
+	search_command.date_format_pref = gsearchtool_gconf_get_string ("/apps/nautilus/preferences/date_format");
 
 	gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.stop_button);
 	gtk_widget_show (interface.stop_button);
@@ -1432,6 +1512,7 @@ spawn_search_command (gchar *command)
 
 	g_io_channel_unref (ioc_stdout);
 	g_io_channel_unref (ioc_stderr);
+	g_strfreev (argv);
 }
   
 static GtkWidget *
@@ -1440,6 +1521,7 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 	GtkWidget *hbox;
 	GtkWidget *label;
 	GtkWidget *entry;
+	GtkWidget *entry_hbox;
 	GtkWidget *button;
 	
 	hbox = gtk_hbox_new (FALSE, 12);
@@ -1464,13 +1546,15 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 			label = gtk_label_new_with_mnemonic (desc);
 			g_free (desc);
 		}
+		
+		/* add description label */
 		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 		
 		if (templates[opt->constraint_id].type == SEARCH_CONSTRAINT_TEXT) {
 			entry = gtk_entry_new();
 			if (value != NULL) {
 				gtk_entry_set_text (GTK_ENTRY(entry), value);
-				opt->data.text = g_strdup (value);
+				opt->data.text = value;
 			}
 		}
 		else {
@@ -1484,8 +1568,11 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 		
 		if (interface.is_gail_loaded)
 		{
-			add_atk_namedesc (GTK_WIDGET(entry), _("Search Rule Value Entry"), 
-					  _("Enter a value for search rule"));
+			gchar *text = remove_mnemonic_character (templates[opt->constraint_id].desc);
+			gchar *desc = g_strdup_printf (_("'%s' entry"), _(text));
+			add_atk_namedesc (GTK_WIDGET(entry), desc, _("Enter a value for search rule"));
+			g_free (desc);
+			g_free (text);
 		}
 		
 		gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (entry));
@@ -1501,8 +1588,17 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 				  G_CALLBACK (constraint_activate_cb),
 				  NULL);
 				  
-		/* add label and text field */
-		gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
+		/* add text field */
+		entry_hbox = gtk_hbox_new (FALSE, 6);
+		gtk_box_pack_start(GTK_BOX(hbox), entry_hbox, TRUE, TRUE, 0);
+		gtk_box_pack_start(GTK_BOX(entry_hbox), entry, TRUE, TRUE, 0);
+		
+		/* add units label */
+		if (templates[opt->constraint_id].units != NULL)
+		{
+			label = gtk_label_new_with_mnemonic (_(templates[opt->constraint_id].units));
+			gtk_box_pack_start (GTK_BOX(entry_hbox), label, FALSE, FALSE, 0);
+		}
 		
 		break;
 	default:
@@ -1569,7 +1665,6 @@ static GtkWidget *
 create_additional_constraint_section (void)
 {
 	GtkWidget *hbox;
-	GtkWidget *label;
 	gchar *desc;
 
 	interface.constraint = gtk_vbox_new (FALSE, 6);	
@@ -1578,13 +1673,13 @@ create_additional_constraint_section (void)
 	gtk_box_pack_end (GTK_BOX(interface.constraint), hbox, FALSE, FALSE, 0);
 
 	desc = g_strconcat (LEFT_LABEL_SPACING, _("A_vailable options:"), NULL);
-	label = gtk_label_new_with_mnemonic (desc);
+	interface.constraint_menu_label = gtk_label_new_with_mnemonic (desc);
 	g_free (desc);
 
-	gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(hbox), interface.constraint_menu_label, FALSE, FALSE, 0);
 	
 	interface.constraint_menu = gtk_option_menu_new ();
-	gtk_label_set_mnemonic_widget (GTK_LABEL(label), GTK_WIDGET(interface.constraint_menu));
+	gtk_label_set_mnemonic_widget (GTK_LABEL(interface.constraint_menu_label), GTK_WIDGET(interface.constraint_menu));
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(interface.constraint_menu), make_list_of_templates());
 	gtk_box_pack_start (GTK_BOX(hbox), interface.constraint_menu, TRUE, TRUE, 0);
 
@@ -1631,7 +1726,7 @@ create_search_results_section (void)
 	gtk_box_pack_start (GTK_BOX (hbox), interface.results_label, FALSE, FALSE, 0);
 	
 	window = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_NONE);	
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_IN);
 	gtk_container_set_border_width (GTK_CONTAINER(window), 0);
 	gtk_widget_set_size_request (window, 530, 160); 
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(window),
